<?php

namespace Teknisa\DF\Factories;

use Doctrine\ORM\EntityManager;

class VencimentoFactory
{
    private $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function deletaVencimentos($tableName, $vencimento) {
        $sql = "DELETE FROM $tableName WHERE CDFILIAL = :P_CDFILIAL AND NRLANCTONF = :P_NRLANCTONF";
        
        $params = array(
            "P_CDFILIAL"    => $vencimento["CDFILIAL"],
            "P_NRLANCTONF"  => $vencimento["NRLANCTONF"]
        );
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
        
    public function getFormasPagamento($cdforneced) {
        $sql = "SELECT F.CDFORMPGTO,
                  F.IDTPFORPGTFO,
                  F.NRPARCPGTOFO,
                  F.NRDIAPGFIXFO,
                  F.IDUTDIAPGTFO,
                  FP.NMFORMPGTO,
                  FP.IDTIPODTPGTO,
                  FP.IDTPPERIODO,
                  P.NRDIASPGTOFO,
                  P.VRPERCPGTOFO,
                  FP.IDREFECALCPARC,
                  FP.IDCONSDIAUTIL
            FROM FORNECEDOR F, FORMPGTO FP, PRAZOPGTFORN P
            WHERE F.CDFORNECED = :P_FORNECED
            AND F.CDFORMPGTO = FP.CDFORMPGTO(+)
            AND F.CDFORNECED = P.CDFORNECED(+)";
            
        $params = array(
            "P_FORNECED" => $cdforneced
        );
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getPagamentoForn($cdforneced) {
        $sql = "SELECT F.CDFORMPGTO,
                  F.IDTPFORPGTFO,
                  F.NRPARCPGTOFO,
                  F.NRDIAPGFIXFO,
                  F.IDUTDIAPGTFO,
                  FP.NMFORMPGTO,
                  FP.IDTIPODTPGTO,
                  FP.IDTPPERIODO,
                  FP.IDREFECALCPARC,
                  FP.IDCONSDIAUTIL
            FROM FORNECEDOR F, FORMPGTO FP
            WHERE F.CDFORNECED = :P_FORNECED
            AND F.CDFORMPGTO = FP.CDFORMPGTO(+)";
            
        $params = array(
            "P_FORNECED" => $cdforneced
        );
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getFeriFili($cdfilial, $dtinicial, $dtfinal) {
        $sql = "SELECT
                    DECODE(P.IDCONSCALVENNF, 'F', D1.NRDIASFERIFILI, 'C', NRDIASFERICOMP,
                           NRDIASFERIBANC) AS NRDIAS
                FROM
                    (
                        SELECT
                            NVL(IDCONSCALVENNF, 'F') AS IDCONSCALVENNF
                        FROM
                            PARAMFILIAL
                        WHERE
                            CDFILIAL = :P_CDFILIAL
                    ) P,
                    (
                        SELECT
                            COUNT(*) AS NRDIASFERIFILI
                        FROM
                            FERIFILI F
                        WHERE
                            F.CDFILIAL = :P_CDFILIAL
                            AND F.DTFERIFILI BETWEEN :P_DTINICIAL AND :P_DTFINAL
                    ) D1,
                    (
                        SELECT
                            COUNT(*) AS NRDIASFERICOMP
                        FROM
                            FERICOMP F
                        WHERE
                            F.CDFILIAL = :P_CDFILIAL
                            AND F.DTFERICOMP BETWEEN :P_DTINICIAL AND :P_DTFINAL
                    ) D2,
                    (
                        SELECT
                            COUNT(*) AS NRDIASFERIBANC
                        FROM
                            FERIBANC F
                        WHERE
                            F.CDFILIAL = :P_CDFILIAL
                            AND F.DTFERIBANC BETWEEN :P_DTINICIAL AND :P_DTFINAL
                    ) D3";
        
        $params = array(
            "P_CDFILIAL"    => $cdfilial,
            "P_DTINICIAL"   => $dtinicial,
            "P_DTFINAL"     => $dtfinal
        );
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDiasPgto($cdformpgto) {
        $sql = "SELECT NRDIAINIPGTO, NRDIAFINPGTO, NRDIAPGTOVAR, NRMESFORMPGT, NVL(NRNUMMESPGTO, 1) AS NRNUMMESPGTO, NVL(NRDIAPGTOSEMANA, '00') AS NRDIAPGTOSEMANA
                    FROM DIAPGTO
                WHERE CDFORMPGTO = :P_FORMPGTO";
                
        $params = array(
            "P_FORMPGTO"    => $cdformpgto
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();        
    }
    
    public function getAutoforne($cdfildest, $cdfillanc, $nrautoforn) {
        $sql = "SELECT AUTOFORNE.CDFORMPGTO,
                         AUTOFORNE.IDTPFORPGTAF,
                         AUTOFORNE.NRPARCPGTOAF,
                         AUTOFORNE.NRDIAPGFIXAF,
                         AUTOFORNE.IDUTDIAPGTAF,
                         FORMPGTO.NMFORMPGTO,
                         FORMPGTO.IDTIPODTPGTO,
                         FORMPGTO.IDTPPERIODO,
                         PRAZOPGTAF.NRDIASPGTOAF,
                         PRAZOPGTAF.VRPERCPGTOAF,
                         FORMPGTO.IDREFECALCPARC,
                         FORMPGTO.IDCONSDIAUTIL,
                         FORMPGTO.IDREFECALCPARC
                FROM AUTOFORNE, FORMPGTO, PRAZOPGTAF
                WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST
                        AND AUTOFORNE.CDFILLANC = :P_CDFILLANC
                        AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN
                        AND AUTOFORNE.CDFORMPGTO = FORMPGTO.CDFORMPGTO(+)
                        AND AUTOFORNE.CDFILDEST = PRAZOPGTAF.CDFILDEST(+)
                        AND AUTOFORNE.CDFILLANC = PRAZOPGTAF.CDFILLANC(+)
                        AND AUTOFORNE.NRAUTOFORN = PRAZOPGTAF.NRAUTOFORN(+)";
                        
        $params = array(
            "P_CDFILDEST"   => $cdfildest,
            "P_CDFILLANC"   => $cdfillanc,
            "P_NRAUTOFORN"  => $nrautoforn
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();        
    }

}